.. PyRTL rtllib master file

.. default-domain:: pyrtl.rtllib

===========
RTL Library
===========

Useful circuits, functions, and testing utilities.

Adders
------

.. automodule:: pyrtl.rtllib.adders
   :members:
   :special-members:
   :undoc-members:
   :exclude-members: __dict__,__weakref__,__module__

AES-128
-------

.. automodule:: pyrtl.rtllib.aes
   :members:
   :undoc-members:
   :exclude-members: __dict__,__weakref__,__module__

Barrel
------

.. automodule:: pyrtl.rtllib.barrel
   :members:
   :special-members:
   :undoc-members:
   :exclude-members: __dict__,__weakref__,__module__

Library Utilities
-----------------

.. automodule:: pyrtl.rtllib.libutils
   :members:
   :special-members:
   :undoc-members:
   :exclude-members: __dict__,__weakref__,__module__

Multipliers
-----------

.. automodule:: pyrtl.rtllib.multipliers
   :members:
   :special-members:
   :undoc-members:
   :exclude-members: __dict__,__weakref__,__module__

Muxes
-----

.. automodule:: pyrtl.rtllib.muxes
   :members:
   :special-members:
   :undoc-members:
   :exclude-members: __dict__,__weakref__,__module__,__exit__

Matrix
------

.. automodule:: pyrtl.rtllib.matrix
   :members:
   :special-members: __init__
   :undoc-members:
   :exclude-members: __dict__,__weakref__,__module__

Testing Utilities
-----------------

.. automodule:: pyrtl.rtllib.testingutils
   :members:
   :special-members:
   :exclude-members: __dict__,__weakref__,__module__
